:github_url: https://github.com/vhewes/pynuml

pynuml Documentation
====================

**pynuml** is a python package providing a data interface for machine learning in neutrino physics. It utilises the :NuML: HDF5 event file format to efficiently preprocess physics events into ML objects for training neural networks. It is designed to abstract away many aspects of a typical ML workflow:
- Efficiently iterate over large HDF5 datasets
- Generate semantic and instance labels for particles
- Preprocess events into ML objects

.. toctree::
   :maxdepth: 1
   :caption: Installation

   install/installation

.. toctree::
   :maxdepth: 1
   :caption: Getting Started
